import os
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))


# plot parameters
fontsize = 11
lfontsize = 11
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1
ax_lw = 1


# load diF-TES-ADT absorption and PL
dt_abs_RT = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_abs_RT.csv'), index_col=0, header=0, squeeze=True)
dt_pl = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_pl.csv'), index_col=0, header=0)


# load pentacene polarised absorption
pn_abs_RT = pd.read_csv(os.path.join(here, 'data', 'pentacene_abs_RT.csv'), index_col=0, header=0)


# create the plotting grid
fig, axes = plt.subplots(nrows=2,
                         ncols=1,
                         gridspec_kw={'hspace': 0.32},
                         figsize=(7, 7.5))


# diF-TES-ADT abs/pl
colours = ['blue', 'red', 'lime']
                     
ax = axes[0]

l1, = ax.plot(dt_abs_RT.index.values, dt_abs_RT.values, color=colours[0], label='Absorbance (RT)', linewidth=linewidth)
ax.fill_between(dt_abs_RT.index.values, dt_abs_RT.values, color=colours[0], alpha=alpha)

ax2 = ax.twinx()

l2, = ax2.plot(dt_pl.index.values, dt_pl['RT PL (norm.)'].values, color=colours[1], label='PL (RT)', linewidth=linewidth)
ax2.fill_between(dt_pl.index.values, dt_pl['RT PL (norm.)'].values, color=colours[1], alpha=alpha)

l3, = ax2.plot(dt_pl.index.values, dt_pl['100K PL (norm.)'].values, color=colours[2], label='PL (100K)', linewidth=linewidth)
ax2.fill_between(dt_pl.index.values, dt_pl['100K PL (norm.)'].values, color=colours[2], alpha=alpha)

ax.set_xlim([400, 800])
ax.set_ylim([0, 0.225])
ax2.set_ylim([0, 1.1])
ax.legend((l1, l2, l3), (l1.get_label(), l2.get_label(), l3.get_label()), loc='upper right', frameon=False, fontsize=lfontsize)
ax.set_xlabel('Wavelength (nm)', fontsize=fontsize)
ax.set_ylabel('Absorbance', fontsize=fontsize)
ax2.set_ylabel('PL intensity (norm.)', fontsize=fontsize)

ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax2 = uf.linearticks(ax2, ymajorsep=0.2, yminorsep=0.1)
ax2.tick_params(axis='y', which='major', labelsize=fontsize, width=1.4, length=6)
ax2.tick_params(axis='y', which='minor', labelsize=fontsize, width=1.4, length=6*0.5)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=0.05, yminorsep=0.025)

#ax.set_title('diF-TES-ADT film spectra', fontsize=12)

# pentacene abs
colours = ['c', 'magenta']

ax = axes[1]

ax.plot(pn_abs_RT.index.values, pn_abs_RT['absorption A axis (OD)'].values, color=colours[0], label='Absorbance || a-axis', linewidth=linewidth)
ax.fill_between(pn_abs_RT.index.values, pn_abs_RT['absorption A axis (OD)'].values, color=colours[0], alpha=alpha)

ax.plot(pn_abs_RT.index.values, pn_abs_RT['absorption B axis (OD)'].values, color=colours[1], label='Absorbance || b-axis', linewidth=linewidth)
ax.fill_between(pn_abs_RT.index.values, pn_abs_RT['absorption B axis (OD)'].values, color=colours[1], alpha=alpha)

ax.set_xlim([400, 800])
ax.set_ylim([0, 0.65])
ax.legend(loc='upper left', frameon=False, fontsize=lfontsize)
ax.set_xlabel('Wavelength (nm)', fontsize=fontsize)
ax.set_ylabel('Absorbance', fontsize=fontsize)

ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=0.1, yminorsep=0.05)

#ax.set_title('Pentacene crystal 1 absorption', fontsize=12)

# save the figure
fig.savefig('fig1_cf.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')

