import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 11
lfontsize = 11
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1
ax_lw = 1


# load data
dt_s_100K = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_spectra_100K_10e18cm3.csv'), header=0, index_col=0)


# create plotting grid
fig, ax = plt.subplots(figsize=(7, 4.5))


ax.plot(dt_s_100K.index.values, dt_s_100K['0-2ns'].values, color='darkred', label='0ns', linewidth=linewidth)
ax.fill_between(dt_s_100K.index.values, dt_s_100K['0-2ns'].values, color='darkred', alpha=0.1, linewidth=0)

ax.plot(dt_s_100K.index.values, dt_s_100K['20-30ns'].values, color='blue', label='20ns', linewidth=linewidth)
ax.fill_between(dt_s_100K.index.values, dt_s_100K['20-30ns'].values, color='blue', alpha=0.15, linewidth=0)

ax.plot(dt_s_100K.index.values, dt_s_100K['200-400ns'].values, color='teal', label='200ns', alpha=0.7, linewidth=linewidth)
ax.plot(dt_s_100K.index.values, dt_s_100K['1000-2000ns'].values, color='black', label=r'1$\mu$s', alpha=0.5, linewidth=linewidth)
ax.plot(dt_s_100K.index.values, dt_s_100K['10000-15000ns'].values, color='purple', label=r'10$\mu$s', alpha=0.3, linewidth=linewidth)

ax.axvline(623, color='k', alpha=0.3)
ax.text(630, 1.06, r'$2\times\mathrm{E}_{\mathrm{T}_1}-\hbar\omega_{{vib}}$', fontsize=lfontsize, alpha=1)

ax.set_xlim([545, 805])
ax.set_ylim([0, 1.15])
ax.set_xlabel('Wavelength (nm)', fontsize=fontsize)
ax.set_ylabel('PL intensity (norm.)', fontsize=fontsize)
ax.legend(loc='upper right', frameon=False, fontsize=lfontsize, borderpad=0.6)

ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=0.2, yminorsep=0.1)

fig.savefig('fig2_all.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')
