import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib.gridspec as gridspec
import matplotlib.colors as mcolors
import matplotlib.ticker as mticker
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 11
lfontsize = 11
fullpagewidth = 7
fmt = 'svg'
dpi = 150
linewidth = 1.5
alpha = 0.1
ax_lw = 1

# load data for panel a - pentacene single crystal spectra at 77K
pn_s1_77K = pd.read_csv(os.path.join(here, 'data', 'pentacene_crystal2_spectra.csv'), header=0, index_col=0)
pn_s2_77K = pd.read_csv(os.path.join(here, 'data', 'pentacene_crystal3_spectra.csv'), header=0, index_col=0)

# load data for panel c - FC stuff
#anger4 = pd.read_csv(os.path.join(here, 'data', 'Anger2012_4K.csv'), index_col=0, header=None)
#anger100 = pd.read_csv(os.path.join(here, 'data', 'Anger2012_100K.csv'), index_col=0, header=None)
model = pd.read_csv(os.path.join(here, 'data', 'FranckCondon_model.csv'), index_col=0, header=0)
spectra = pd.read_csv(os.path.join(here, 'data', 'pentacene_crystal2_spectra_energy.csv'), index_col=0, header=0)


# create the plotting grid
fig, axes = plt.subplots(nrows=3, ncols=1, gridspec_kw={'hspace': 0, 'height_ratios': [1, 1.5, 1]}, figsize=(7, 13.5))
axes[1].axis('off')

# panel a
ax = axes[0]
ax.plot(pn_s1_77K.index.values, pn_s1_77K['0-2ns'].values, color='darkred', label='2: 0ns', linewidth=linewidth, alpha=0.4, zorder=3)
ax.plot(pn_s1_77K.index.values, pn_s1_77K['0-2ns smoothed'].values, color='darkred', linestyle='--', label='_nolegend_', linewidth=linewidth, zorder=4)
ax.fill_between(pn_s1_77K.index.values, pn_s1_77K['0-2ns'].values, color='darkred', alpha=0.1, linewidth=0)

ax.plot(pn_s1_77K.index.values, pn_s1_77K['32-64ns'].values, color='blue', label='2: 32ns', linewidth=linewidth, alpha=0.4, zorder=5)
ax.plot(pn_s1_77K.index.values, pn_s1_77K['32-64ns smoothed'].values, color='blue', linestyle='--', label='_nolegend_', linewidth=linewidth, zorder=6)
ax.fill_between(pn_s1_77K.index.values, pn_s1_77K['32-64ns'].values, color='blue', alpha=0.15, linewidth=0)

ax.plot(pn_s2_77K.index.values, pn_s2_77K['20-50ns'].values, color='teal', label='3: 20ns', linewidth=linewidth, alpha=0.4, zorder=2)
ax.plot(pn_s2_77K.index.values, pn_s2_77K['20-50ns smoothed'].values, color='teal', linestyle='--', label='_nolegend_', linewidth=linewidth, zorder=1)

ax.set_xlim([630, 850])
ax.set_ylim([0, 1.3])
ax.set_xlabel('Wavelength (nm)', fontsize=fontsize)
ax.set_ylabel('PL intensity (norm.)', fontsize=fontsize)
leg = ax.legend(loc='upper left', edgecolor='None', framealpha=0.8, fontsize=lfontsize, handletextpad=0.5, handlelength=1.5, ncol=3, columnspacing=2, borderpad=0.6)
for lh in leg.legendHandles: 
    lh.set_alpha(1)
    
ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=0.25, yminorsep=0.125)


# panel c
ax = axes[2]
#ax.plot(anger4.index, anger4, color='m', linewidth=3, alpha=0.6, label='Ref. 52 4K')
#ax.plot(anger100.index, anger100, color='g', linewidth=3, alpha=0.5, label='Ref. 52 100K')

ax.plot(spectra.index, spectra['0-2ns'], color='darkred', linewidth=linewidth, alpha=0.25, label='2: 0ns')
ax.plot(spectra.index, spectra['32-64ns'], color='blue', linewidth=linewidth, alpha=0.25, label='2: 32ns')

ax.plot(model.index, model['FC'], 'k--', label='Franck-Condon')
#ax.plot(model.index, model['FC_sup0'], 'k:', label='_nolegend_')

ax.set_ylim([0, 1.02])
ax.set_xlim([1.25, 1.95])

ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax.set_xlabel('Energy (eV)', fontsize=fontsize)
ax.set_ylabel('PL intensity (arb.)', fontsize=fontsize)
ax = uf.linearticks(ax, xmajorsep=0.1, xminorsep=0.05, ymajorsep=0.2, yminorsep=0.1)

ax.axvline(1.72, color='k', alpha=0.3)
ax.text(1.73, 0.94, r'$2\times\mathrm{E}_{\mathrm{T}_1}$', fontsize=lfontsize, alpha=1, ha='left')

leg = ax.legend(frameon=False, fontsize=lfontsize, loc=(0.03, 0.6), handletextpad=0.5, handlelength=1.5, borderpad=0)
for lh in leg.legendHandles: 
    lh.set_alpha(1)
    
fig.savefig('fig5_ac.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')