import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib.gridspec as gridspec
import matplotlib.colors as mcolors
import matplotlib.ticker as mticker
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 11
lfontsize = 11
fullpagewidth = 7
fmt = 'svg'
dpi = 150
linewidth = 1.5
alpha = 0.1
ax_lw = 1


# Poletayev ps
#psTA = {}
#pulses = ['4.63', '24.8', '46.3', '74.5', '91', '115']
#for pulse in pulses:
#    ta = pd.read_csv(os.path.join(here, 'data', 'Poletayev2014_psTA_{0}uJcm2.csv'.format(pulse)), header=0, index_col=0, squeeze=True)
#    psTA[pulse] = ta
psTA_sim = pd.read_csv(os.path.join(here, 'data', 'Poletayev2014_psTA_simulation.csv'), header=0, index_col=0)

# Poletayev ns
#nsTA = {}
#pulses = ['0.54', '1.7', '5.4', '17', '54', '130']
#for pulse in pulses:
#    ta = pd.read_csv(os.path.join(here, 'data', 'Poletayev2014_nsTA_{0}uJcm2.csv'.format(pulse)), header=0, index_col=0, squeeze=True)
#    nsTA[pulse] = ta
nsTA_sim = pd.read_csv(os.path.join(here, 'data', 'Poletayev2014_nsTA_simulation.csv'), header=0, index_col=0)

# load data for colourmap
trpl = k_all = pd.read_csv(os.path.join(here, 'data', 'pentacene_crystal2_kinetics.csv'), header=0, index_col=0)
trpl.columns = [int(x.replace('.1', '')) for x in trpl.columns]

# load kinetics
kinetics = pd.read_csv(os.path.join(here, 'data', 'pentacene_crystal2_kinetic_slices.csv'), header=0, index_col=0)
kinetics_sim = pd.read_csv(os.path.join(here, 'data', 'TT_simulation_kinetics.csv'), header=0, index_col=0, squeeze=True)

# load fluence dep
timeranges = ['2_4', '5_10', '10_20', '20_50']
power_dep = {}
for tr in timeranges:
    powerd = pd.read_csv(os.path.join(here, 'data', '{0}ns_fluence.csv'.format(tr)), header=0, index_col=0)
    power_dep[tr] = powerd
power_dep_sim = pd.read_csv(os.path.join(here, 'data', 'simulated_TT_fluence.csv'), header=0, index_col=0)
    

# create the plotting grid
fig = plt.figure(figsize=(14, 11.5))

outergrid = gridspec.GridSpec(
    nrows=2,
    ncols=2,
    wspace=0.2,
    hspace=0.23,
    height_ratios=[1, 1.6],
    figure=fig)

pdepgrid = gridspec.GridSpecFromSubplotSpec(
    nrows=2,
    ncols=2,
    subplot_spec=outergrid[1, 1],
    hspace=0.1,
    wspace=0.2)

cbaxgrid = gridspec.GridSpecFromSubplotSpec(
    nrows=2,
    ncols=3,
    subplot_spec=outergrid[1, 0],
    width_ratios=[1, 0.03, 0.1],
    height_ratios=[1.2, 1],
    wspace=0.1,
    hspace=0.1)

# set axes
axa = plt.subplot(outergrid[0, 0])
axb = plt.subplot(outergrid[0, 1])

cbax = plt.subplot(cbaxgrid[0, 1])
axc = plt.subplot(cbaxgrid[0, 0])
axd = plt.subplot(cbaxgrid[1, 0])

axe1 = plt.subplot(pdepgrid[0, 0])
axe2 = plt.subplot(pdepgrid[0, 1])
axe3 = plt.subplot(pdepgrid[1, 0])
axe4 = plt.subplot(pdepgrid[1, 1])

# remove parts of plot that will be blank
plt.subplot(cbaxgrid[0, 2]).axis('off')
plt.subplot(cbaxgrid[1, 1]).axis('off')
plt.subplot(cbaxgrid[1, 2]).axis('off')


# panel a
ax = axa
pulses = ['4.63', '24.8', '46.3', '74.5', '91', '115']
markers = ['s', 'o', '^', 'v', 'D', '<']
colours = ['green', 'yellowgreen', 'yellow', 'darkorange', 'red', 'black']
for i, pulse in enumerate(pulses):
#    ta = psTA[pulse]
    sim = psTA_sim[pulse]
    ax.plot(sim.index, sim, color=colours[i], )
#    ax.plot(ta.index, ta, color=colours[i], marker=markers[i], linestyle='None', alpha=1, mew=0, ms=5, label='{0}$\mu$Jcm$^{{-2}}$'.format(pulse))
    
#ax.set_xlim([-50, ta.index.max()])
ax.set_xlim([-50, 1500])
ax.set_ylim([0.4, 1.1])
ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax.set_xlabel('Time (ps)', fontsize=fontsize)
ax.set_ylabel(r'$\Delta$T/T (norm.)', fontsize=fontsize)
ax = uf.linearticks(ax, xmajorsep=400, xminorsep=100, ymajorsep=0.1, yminorsep=0.05)
leg = ax.legend(frameon=False, ncol=2, fontsize=lfontsize, handletextpad=0.1, columnspacing=0.3, labelspacing=0.1, loc=(0.07, 0.03), borderpad=0)
for lh in leg.legendHandles: 
    lh.set_alpha(1)
ax.text(0.02, 0.96, 'lines: model', fontsize=lfontsize, transform=ax.transAxes, va='top', ha='left')


# panel b
ax = axb
pulses = ['0.54', '1.7', '5.4', '17', '54', '130']
markers = ['*', 'D', 'v', '^', 'o', 's']
colours = ['dodgerblue', 'green', 'yellowgreen', 'darkorange', 'red', 'black']
for i, pulse in enumerate(pulses):
#    ta = nsTA[pulse]
    sim = nsTA_sim[pulse]
    ax.loglog(sim.index, sim, color=colours[i], )
#    ax.loglog(ta.index, ta, color=colours[i], marker=markers[i], linestyle='None', alpha=1, mew=0, ms=5, label='{0}$\mu$Jcm$^{{-2}}$'.format(pulse))
    
#ax.set_xlim([0.2, ta.index.max()])
ax.set_xlim([0.2, 800])
ax.set_ylim([1e-6, 2e-2])
ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax.set_xlabel('Time (ns)', fontsize=fontsize)
ax.set_ylabel(r'|$\Delta$T/T|', fontsize=fontsize)
ax = uf.logticks(ax)
leg = ax.legend(frameon=False, ncol=2, fontsize=lfontsize, handletextpad=0.1, columnspacing=0.3, labelspacing=0.1, loc=(0.07, 0.03), borderpad=0)
for lh in leg.legendHandles: 
    lh.set_alpha(1)
ax.text(0.98, 0.96, 'lines: model', fontsize=lfontsize, transform=ax.transAxes, va='top', ha='right')


# panel c - colourmap
ax = axc
nlevels = 51
x = trpl.columns.values
y = trpl.index.values
X, Y = np.meshgrid(x, y)
Z = trpl.values
Z[Z < 1e-5] = 1e-5
levels = np.logspace(-5, 0, nlevels)
cs = ax.contourf(X, Y, Z, levels, norm=mcolors.LogNorm(), cmap=plt.cm.inferno, extend='both', zorder=-20)
for c in cs.collections:
    c.set_edgecolor('face')
    #c.set_rasterized(True)
ax.set_rasterization_zorder(-10)
ax.set_ylim([630, 850])
ax.set_xlim([-1, max(x)])
ax.set_xscale('symlog', linthreshx=1, linscalex=0.2)
ax.xaxis.set_major_locator(mticker.FixedLocator([0, 1, 10, 100]))
ax.xaxis.set_minor_locator(mticker.FixedLocator([-0.5, 0.5, 2, 3, 4, 5, 6, 7, 8, 9, 20, 30, 40, 50, 60, 70, 80, 90, 200, 300]))
#ax.set_xticklabels([-4, 0, 4, 10, 100])
cbar = fig.colorbar(cs, cax=cbax, orientation='vertical', ticks=np.logspace(-5, 0, 6))
cbar.ax.tick_params(axis='y', which='major', labelsize=fontsize, width=ax_lw, length=6)
ax.set_ylabel('Wavelength (nm)', fontsize=fontsize)
ax.set_xticklabels([])
cbar.ax.set_ylabel('PL intensity (norm.)', fontsize=fontsize, labelpad=10)
ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax = uf.linearticks(ax, ymajorsep=50, yminorsep=10)

ax.axhline(690, linewidth=3, linestyle='--', color='darkred', alpha=0.5)
ax.axhline(750, linewidth=3, linestyle='--', color='blue', alpha=0.5)


# panel d - kinetics
ax = axd
S1wl = '690'
TTwl = '750'
ax.errorbar(kinetics.index[kinetics.index < 20], kinetics[S1wl].values[kinetics.index < 20], yerr=kinetics['{0}err'.format(S1wl)].values[kinetics.index < 20], color='darkred', linestyle='None', marker='x', capsize=6, label='PL, {0}nm'.format(S1wl))
ax.errorbar(kinetics.index, kinetics[TTwl].values, yerr=kinetics['{0}err'.format(TTwl)].values, color='blue', linestyle='None', marker='x', capsize=6, label='PL, {0}nm'.format(TTwl))
ax.plot(kinetics_sim.index, kinetics_sim, 'k--', linewidth=linewidth, label=r'$^1$(TT) prediction')
ax.plot(kinetics_sim.index[kinetics_sim.index > 20], 20/kinetics_sim.index[kinetics_sim.index > 20]**2, 'k--', linewidth=4, alpha=0.3, label='_nolegend_')
ax.text(200, 0.002, 'slope -2', fontsize=lfontsize, rotation=-26, va='bottom', ha='right', color='0.3')
ax.set_xlim([-1, max(x)])
ax.set_xscale('symlog', linthreshx=1, linscalex=0.2)
ax.set_yscale('log')
ax.set_ylim([1e-5, 2])
ax.xaxis.set_major_locator(mticker.FixedLocator([0, 1, 10, 100]))
ax.xaxis.set_minor_locator(mticker.FixedLocator([-0.5, 0.5, 2, 3, 4, 5, 6, 7, 8, 9, 20, 30, 40, 50, 60, 70, 80, 90, 200, 300]))
ax = uf.logticks(ax, which='y')
ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
ax.set_ylabel('PL intensity (norm.)', fontsize=fontsize)
ax.set_xlabel('Time (ns)', fontsize=fontsize)
handles, labels = ax.get_legend_handles_labels()
leg1 = ax.legend(handles=handles[1:], labels=labels[1:], frameon=False, fontsize=lfontsize, handletextpad=0.2, handlelength=1.5, borderpad=0, loc=(0.03, 0.06))
ax.add_artist(leg1)
leg2 = ax.legend(handles=[handles[0]], labels=[labels[0]], frameon=False, fontsize=lfontsize, handletextpad=0.2, handlelength=1.5, borderpad=0, loc=(0.4, 0.83))


# panel e - fluence dep
axe_list = [axe1, axe2, axe3, axe4]
TTwl = '750'
timeranges = ['2_4', '5_10', '10_20', '20_50']

for i, tr in enumerate(timeranges):
    ax = axe_list[i]
    data = power_dep[tr]
    sim = power_dep_sim[tr]
    data = data/1e4
    sim = sim/1e4
    
    ax.errorbar(data.index, data['{0}'.format(TTwl)], yerr=data['{0}err'.format(TTwl)], marker='x', mfc='None', capsize=6, linestyle='None', label='PL, 750nm', color='b')
    ax.plot(sim.index, sim, 'k--', label=r'$^1$'+'(TT) prediction')

    ax = uf.format_axes(ax, labelsize=fontsize, linewidth=ax_lw)
    
    # if i == 0:
    #     yfactor = data['{0}'.format(TTwl)].max()/data['{0}'.format(TTwl)].min()
    
    # ax.set_ylim([0.4*data['{0}'.format(TTwl)].min(), 1.1*data['{0}'.format(TTwl)].min()*yfactor])
    if i == 0:
        ax = uf.linearticks(ax, xmajorsep=40, xminorsep=10, ymajorsep=4, yminorsep=2)
        ax.set_xticklabels([])
    elif i == 1:
        ax = uf.linearticks(ax, xmajorsep=40, xminorsep=10, ymajorsep=4, yminorsep=2)
        ax.set_xticklabels([])
    elif i == 2:
        ax = uf.linearticks(ax, xmajorsep=40, xminorsep=10, ymajorsep=2, yminorsep=1)
        ax.set_xlabel(r'Pulse energy ($\mu$Jcm$^{-2}$)', fontsize=fontsize)
        ax.set_ylabel(r'PL (counts/10$^4$)', fontsize=fontsize)
    elif i == 3:
        ax = uf.linearticks(ax, xmajorsep=40, xminorsep=10, ymajorsep=2, yminorsep=1)
        
    ymin, ymax = data['{0}'.format(TTwl)].values[0], data['{0}'.format(TTwl)].values[-1]
    ax.axhline(ymin, color='0.5', linestyle=':', linewidth=1)
    ax.annotate('', xy=(137, ymin), xytext=(137, ymax*0.93), arrowprops=dict(arrowstyle='<-', color='0.5'), fontsize=lfontsize)
    ax.text(134, ymax*0.75, 'x{0:.0f}'.format(ymax/ymin), fontsize=lfontsize, ha='right', va='top', color='0.5')
    
    ax.text(0.03, 0.97, '{0}-{1}ns'.format(tr.split('_')[0], tr.split('_')[1]), fontsize=fontsize, transform=ax.transAxes, va='top')

handles, labels = ax.get_legend_handles_labels()
leg1 = axe_list[2].legend(handles=[handles[-1]], labels=[labels[-1]], frameon=False, fontsize=lfontsize, loc=(0.16, 0.03), handlelength=1.5, handletextpad=0.2)
leg2 = axe_list[3].legend(handles=[handles[0]], labels=[labels[0]], frameon=False, fontsize=lfontsize, loc=(0.14, 0.02), handlelength=1.5, handletextpad=0.2)

fig.savefig('fig6_all.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')