import os
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))


# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1

lleft = 0.1


# load data
simulations = pd.read_csv(os.path.join(here, 'data', 'simulations.csv'), index_col=0, header=0)
measured = pd.read_csv(os.path.join(here, 'data', 'measured_corrected.csv'), index_col=0, header=0)


# create the plotting grid
fig, ax = plt.subplots(figsize=(7, 5))

offset = 0.6

oop, = ax.plot(measured.index, measured['out-of-plane']+0*offset, color='b', linewidth=linewidth)
aca, = ax.plot(measured.index, measured['all chi angles']+1*offset, color='seagreen', linewidth=linewidth)
ip, = ax.plot(measured.index, measured['in-plane']+2*offset, color='darkorange', linewidth=linewidth)
sim1, = ax.plot(simulations.index, simulations['Simulated (1)']+2*offset+1, color='cyan', linewidth=linewidth)
sim2, = ax.plot(simulations.index, simulations['Simulated (2)']+2*offset+1, color='violet', linewidth=linewidth, alpha=0.8)

ax.set_xlim([0.25, 2])
ax.set_ylim([-0.1, 3.6])
ax.set_yticklabels([])
ax.set_yticks([0, offset, 2*offset, 2*offset+1])
ax.set_ylabel('Intensity (norm.)', fontsize=fontsize)
ax.set_xlabel(r'Q ($\rm{\AA}^{-1}$)', fontsize=fontsize)
ax = uf.format_axes(ax, labelsize=fontsize)
ax = uf.linearticks(ax, xmajorsep=0.2, xminorsep=0.1)


leg1 = ax.legend(handles=[oop], labels=['out-of-plane'], fontsize=lfontsize, frameon=False, loc=(lleft, 0.03), handlelength=1.5, handletextpad=0.5)
ax.add_artist(leg1)
leg2 = ax.legend(handles=[aca], labels=[r'all $\chi$ angles'], fontsize=lfontsize, frameon=False, loc=(lleft, 0.20), handlelength=1.5, handletextpad=0.5)
ax.add_artist(leg2)
leg3 = ax.legend(handles=[ip], labels=['in-plane'], fontsize=lfontsize, frameon=False, loc=(lleft, 0.37), handlelength=1.5, handletextpad=0.5)
ax.add_artist(leg3)
ax.legend(handles=[sim1, sim2], labels=['sim. 1', 'sim. 2'], fontsize=lfontsize, frameon=False, loc=(lleft, 0.62), handlelength=1.5, handletextpad=0.5)


# save the figure
fig.savefig('linecuts.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')

