import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib.ticker as mticker
from matplotlib.legend_handler import HandlerTuple
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))


# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1


 # load the data into a dict
temperatures = ['100K']
data = {}
for temp in temperatures:
    data[temp] = {}
    datas = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_{0}_MCR-ALS_TT.csv'.format(temp)), header=0, index_col=0)
    data[temp]['datas'] = datas
    model = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_{0}_model.csv'.format(temp)), header=0, index_col=0)
    data[temp]['model'] = model


# create the plotting grid
fig, ax = plt.subplots(figsize=(7, 4))


# plot the data and model in the top grid
alphas = [0.3, 0.65, 1.0]
markers = ['o', 's', '^']
linestyles = [':', '--', '-']

temp = '100K'
    
datas = data[temp]['datas']
model = data[temp]['model']

for i, N0 in enumerate([1e17, 1e18, 1e19]):
    
    ttdata = datas[str(N0)]
    ttmodel = model[str(N0)]
    label = r'{0} cm$^{{-3}}$'.format(uf.fsci(float(N0)))
    
    ax.loglog(ttdata.index.values, ttdata.values, markersize=6, alpha=alphas[i], marker=markers[i], color='b', linestyle='None', mfc='None', markeredgewidth=1, label=label)
    ax.loglog(ttmodel.index.values, ttmodel, color='r', linestyle=linestyles[i], linewidth=1, label=label, alpha=0.75)
    ax.set_xlim([1, 1e5])
    ax.set_ylim([1e-7, 2])
    ax.set_xlabel('Time (ns)', fontsize=fontsize)
    ax.set_ylabel(r'$^1$(TT) population (norm.)', fontsize=fontsize)
    
ha, la = ax.get_legend_handles_labels()    
ax.legend(handles=zip(ha[::2], ha[1::2]), labels=la[::2], numpoints=1, handler_map={tuple: HandlerTuple(ndivide=None)}, edgecolor='None', framealpha=0.8, loc='upper right', fontsize=lfontsize, borderpad=0)
ax.yaxis.set_major_locator(mticker.LogLocator(numticks=12))
ax.yaxis.set_minor_locator(mticker.LogLocator(subs=np.linspace(0.1, 0.9, 9), numticks=12))
ax.xaxis.set_major_locator(mticker.LogLocator(numticks=12))
ax.xaxis.set_minor_locator(mticker.LogLocator(subs=np.linspace(0.1, 0.9, 9), numticks=12))     
ax.text(2, 4e-5, temp, fontsize=fontsize)

ax.axvline(100, color='k', alpha=0.3, linewidth=linewidth)
ax.axvline(4000, color='k', alpha=0.3, linewidth=linewidth)

ax.text(4, 1.7e-7, 'region I', fontsize=fontsize)
ax.text(200, 1.7e-7, 'region II', fontsize=fontsize)
ax.text(7e3, 1.7e-7, 'region III', fontsize=fontsize)

ax = uf.logticks(ax)
ax = uf.format_axes(ax, labelsize=fontsize)

fig.savefig('figS14_b.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')