import os
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1


# load data
up_20_30 = pd.read_csv(os.path.join(here, 'data', '20-30ns_up.csv'), header=0, index_col=0)
dn_20_30 = pd.read_csv(os.path.join(here, 'data', '20-30ns_dn.csv'), header=0, index_col=0)
up_100_200 = pd.read_csv(os.path.join(here, 'data', '100-200ns_up.csv'), header=0, index_col=0)
dn_100_200 = pd.read_csv(os.path.join(here, 'data', '100-200ns_dn.csv'), header=0, index_col=0)



# create plotting grid
fig, axes = plt.subplots(nrows=2,
                         ncols=7,
                         gridspec_kw={'hspace': 0.1,
                                      'wspace': 0.1},
                         figsize=(14, 3.5))


magfields = [0, 6, 40, 80, 120, 160, 200]

for c, B in enumerate(magfields):
    
    # upper row: 20-30ns
    ax = axes[0, c]
    spectrum_up = up_20_30[str(B)]
    spectrum_dn = dn_20_30[str(B)]
    ax.plot(spectrum_up.index.values, spectrum_up.values, 'k:', linewidth=linewidth, alpha=0.6, label=r'B$\uparrow$')
    ax.plot(spectrum_dn.index.values, spectrum_dn.values, 'r-', linewidth=linewidth, alpha=0.4, label=r'B$\downarrow$')
    ax.set_xlim([525, 810])
    ax.set_ylim([0, 1.1*max([spectrum_up.max(), spectrum_dn.max()])])
    ax.set_yticks([])
    ax.set_xticklabels([])
    ax.legend(loc='upper right', fontsize=12, frameon=False, borderpad=0, handlelength=1.5, handletextpad=0.5)
    ax.set_title('B = {0}mT'.format(B), fontsize=12)
    ax = uf.linearticks(ax, xmajorsep=100, xminorsep=50)
    ax = uf.format_axes(ax, labelsize=fontsize)
    
    # lower row: 100-200ns
    ax = axes[1, c]
    spectrum_up = up_100_200[str(B)]
    spectrum_dn = dn_100_200[str(B)]
    ax.plot(spectrum_up.index.values, spectrum_up.values, 'k:', linewidth=linewidth, alpha=0.6, label=r'B$\uparrow$')
    ax.plot(spectrum_dn.index.values, spectrum_dn.values, 'r-', linewidth=linewidth, alpha=0.4, label=r'B$\downarrow$')
    ax.set_xlim([525, 810])
    ax.set_ylim([0, 1.1*max([spectrum_up.max(), spectrum_dn.max()])])
    ax.set_yticks([])
    ax.legend(loc='upper right', fontsize=12, frameon=False, borderpad=0, handlelength=1.5, handletextpad=0.5)
    ax.set_xlabel('Wavelength (nm)', fontsize=12)
    ax = uf.linearticks(ax, xmajorsep=100, xminorsep=50)
    ax = uf.format_axes(ax, labelsize=12)
    
axes[1, 0].text(-0.05, 1, 'PL 100-200ns  and 20-30 ns (arb.)', fontsize=12, transform=axes[1, 0].transAxes, va='center', ha='right', rotation='vertical')

fig.savefig('figS27_all.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')
