import os
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))


# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1

fig, axes = plt.subplots(nrows=1, ncols=3, gridspec_kw={'wspace': 0.3}, figsize=(14, 2.33))

for i, xtal in enumerate(['1', '2', '3']):

    # load pentacene thickness data
    pn_th = pd.read_csv(os.path.join(here, 'data', 'pentacene_thickness_{0}.csv'.format(xtal)), index_col=0, header=0)
    
    
    # plot pentacene step height
    ax = axes[i]
    ax.plot(pn_th.index.values, pn_th.values, 'k-')
    
    ax.set_xlim([0, 1.6])
    ax.set_ylim([0, 1.1*pn_th.max().max()])
    ax.set_xlabel(r'Horizontal Distance ($\mu$m)', fontsize=fontsize)
    ax.set_ylabel('Height (nm)', fontsize=fontsize)
    
    ax = uf.format_axes(ax, labelsize=fontsize)
    ymajorsep=50 if i!=1 else 100
    ax = uf.linearticks(ax, xmajorsep=0.5, xminorsep=0.1, ymajorsep=ymajorsep, yminorsep=ymajorsep/2)
    
fig.savefig('figS3_jkl.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')







