import os
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf

here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1


# load data for panel A - kinetics
kinetics = pd.read_csv(os.path.join(here, 'data', 'crystal_kinetics.csv'), index_col=0, header=None, squeeze=True)
newsim = pd.read_csv(os.path.join(here, 'data', 'kinetics_simulation_new_rates.csv'), index_col=0, header=None, squeeze=True)

# load data for panel B - rate constant variation
rates = pd.read_csv(os.path.join(here, 'data', 'kinetics_rate_constant_modification.csv'), index_col=0, header=None, squeeze=True)
rates1 = pd.read_csv(os.path.join(here, 'data', 'kinetics_rate_constant_further_modification.csv'), index_col=0, header=None, squeeze=True)


# create the plotting grid
fig, axes = plt.subplots(nrows=1, ncols=2, gridspec_kw={'wspace': 0.2}, figsize=(14, 4.5))


# panel A
ax = axes[0]
ax.loglog(kinetics.index.values, kinetics.values, marker='s', linestyle='None', color='red', mfc='None', mew=1, ms=6, label='crystal (MFE)')
ax.loglog(newsim.index.values, newsim.values, color='black', alpha=0.6, linestyle='-', linewidth=linewidth, label='further rate modification')

ax.set_xlim([1, 1e5])
ax.set_ylim([1e-5, 2])

ax.set_xlabel('Time (ns)', fontsize=fontsize)
ax.set_ylabel('Integrated PL (norm.)', fontsize=fontsize)

ax.legend(frameon=False, fontsize=lfontsize, loc='upper right', borderpad=0, handlelength=1.5, handletextpad=0.5)

ax = uf.logticks(ax)
ax = uf.format_axes(ax, labelsize=fontsize)


# panel B
ax = axes[1]
ax.axhline(0, color='0.5', linewidth=1)
ax.bar([r'$k_{{{0}}}$'.format(x[1:].replace('_', '-').lower()) for x in rates.index.values], rates.values, color='dodgerblue', label='from film', align='edge', width=-0.4)
ax.bar([r'$k_{{{0}}}$'.format(x[1:].replace('_', '-').lower()) for x in rates1.index.values], rates1.values, color='darkorange', label='additional', align='edge', width=0.4)
ax.set_ylabel('variation (%)', fontsize=fontsize, labelpad=-10)
ax.set_ylim([-100, 220])

ax = uf.linearticks(ax, ymajorsep=50, yminorsep=10)
ax = uf.format_axes(ax, labelsize=fontsize)

ax.legend(frameon=False, fontsize=fontsize)

fig.savefig('figS31_all.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')
