import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib.ticker as mticker
import usefulfunctions as uf


here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1


# load data for spectra for panel a
extspe = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_total_spectra_250K_1e17cm3.csv'), header=0, index_col=0, squeeze=True)

# load data for excimer spectra panel b
exspe = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_excimer_spectra_250K_1e17cm3.csv'), header=0, index_col=0, squeeze=True)

# load excimer kinetics and simulation results for panel c
exkin = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_excimer_kinetics_250K_1e17cm3.csv'), header=0, index_col=0, squeeze=True)
sim = pd.read_csv(os.path.join(here, 'data', 'diF-TES-ADT_simulation_250K_1e17cm3.csv'), header=0, index_col=0)



# create the plotting grid
fig, axes = plt.subplots(nrows=1, ncols=3, gridspec_kw={'wspace': 0.28}, figsize=(14, 3))


# panel a
ax = axes[0]

colours = [plt.cm.tab10(0), plt.cm.tab10(2), plt.cm.tab10(6)]
linestyles = ['-', ':', '--']
times = [4, 20, 500]
alphas = [0.8, 0.6, 0.6]

for i, time in enumerate(times):
    ax.plot(extspe.index.values, extspe[str(time)].values, color=colours[i], linestyle='-', alpha=alphas[i], linewidth=linewidth, label='{0}ns'.format(time))
    #smoothed = extspe[str(time)].rolling(61, center=True).mean()
    #ax.plot(smoothed.index.values, smoothed.values, color=colours[i], linestyle='-', alpha=1, linewidth=1, label='{0}ns'.format(time))

ax.set_xlim([545, 805])
ax.set_ylim([0, 3.2])
    
ax.set_ylabel('PL intensity (norm.)', fontsize=fontsize)
ax.set_xlabel('Wavelength (nm)', fontsize=fontsize)
    
leg = ax.legend(frameon=False, fontsize=13, loc='upper left', borderpad=0, handlelength=1.3, handletextpad=0.3)
for lh in leg.legendHandles: 
    lh.set_alpha(1)

ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=1, yminorsep=0.5)
ax = uf.format_axes(ax, labelsize=fontsize)


# panel b
ax = axes[1]

colours = plt.cm.tab10
times = [4, 12, 20, 40, 100]

for i, time in enumerate(times):
    ax.plot(exspe.index.values, exspe[str(time)].values, color=colours(i), linestyle='-', alpha=0.25, linewidth=linewidth, label='_nolegend_'.format(time))
    smoothed = exspe[str(time)].rolling(61, center=True).mean()
    ax.plot(smoothed.index.values, smoothed.values, color=colours(i), linestyle='-', alpha=1, linewidth=linewidth, label='{0}ns'.format(time))

ax.set_xlim([545, 805])
ax.set_ylim([0, 2.5])
    
ax.set_ylabel('PL intensity (norm.)', fontsize=fontsize)
ax.set_xlabel('Wavelength (nm)', fontsize=fontsize)
    
ax.legend(frameon=False, fontsize=13, loc='upper left', borderpad=0, handlelength=1.3, handletextpad=0.3)

ax = uf.linearticks(ax, xmajorsep=50, xminorsep=10, ymajorsep=1, yminorsep=0.5)
ax = uf.format_axes(ax, labelsize=fontsize)


# panel c
ax = axes[2]

ax.semilogx(sim.index.values, sim['S1'].values, color='darkred', linewidth=linewidth, label=r'S$_1$')
ax.fill_between(sim.index.values, sim['S1'].values, color='darkred', alpha=0.1)

ax.semilogx(sim.index.values, sim['1TT'].values, color='blue', linewidth=linewidth, label=r'$^1$(TT)')
ax.fill_between(sim.index.values, sim['1TT'].values, color='blue', alpha=0.1)

ax.semilogx(sim.index.values, sim['T..T'].values, color='seagreen', linewidth=linewidth, label=r'(T..T)')
ax.fill_between(sim.index.values, sim['T..T'].values, color='seagreen', alpha=0.1)

ax.semilogx(sim.index.values, sim['T1'].values, color='purple', linewidth=linewidth, label=r'T$_1$')
ax.fill_between(sim.index.values, sim['T1'].values, color='purple', alpha=0.1)

ax.semilogx(exkin.index.values, exkin.values, marker='o', mfc='None', markeredgewidth=1, color='darkorange', linestyle='None', label=r'Ex')
ax.fill_between(exkin.index.values, exkin.values, color='darkorange', alpha=0.2)

ax.legend(frameon=False, fontsize=13, loc='upper right', borderpad=0, handlelength=1.3, handletextpad=0.3)

ax.set_xlim([1e-1, 2e4])
ax.set_ylim([0, 1.1])

ax.set_ylabel('Population (norm.)', fontsize=fontsize)
ax.set_xlabel('Time (ns)', fontsize=fontsize)

ax = uf.logticks(ax, which='x')
ax = uf.linearticks(ax, ymajorsep=0.2, yminorsep=0.1)
ax = uf.format_axes(ax, labelsize=fontsize)

fig.savefig('figS32_all.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')
