import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf


here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1


# load data
#anger4 = pd.read_csv(os.path.join(here, 'data', 'Anger2012_4K.csv'), header=None, index_col=0, squeeze=True)
#anger100 = pd.read_csv(os.path.join(here, 'data', 'Anger2012_100K.csv'), header=None, index_col=0, squeeze=True)
#aoki10 = pd.read_csv(os.path.join(here, 'data', 'Aoki2001_10K.csv'), header=None, index_col=0, squeeze=True)
#aoki70 = pd.read_csv(os.path.join(here, 'data', 'Aoki2001_70K.csv'), header=None, index_col=0, squeeze=True)
#he78 = pd.read_csv(os.path.join(here, 'data', 'He2005_78K.csv'), header=None, index_col=0, squeeze=True)
spectra = pd.read_csv(os.path.join(here, 'data', 'pentacene_crystal2_spectra_energy.csv'), header=0, index_col=0)

# create the plotting grid
fig, ax = plt.subplots(figsize=(10, 5))

#ax.plot(anger4.index, anger4, color='m', linewidth=linewidth, alpha=1, label='Ref. 35 4K')
#ax.plot(anger100.index, anger100, color='g', linewidth=linewidth, alpha=1, label='Ref. 35 100K')

#ax.plot(aoki10.index, aoki10, color='c', linestyle='--', linewidth=linewidth, alpha=1, label='Ref. 33 10K')
#ax.plot(aoki70.index, aoki70, color='orange', linestyle='--', linewidth=linewidth, alpha=1, label='Ref. 33 70K')

#ax.plot(he78.index, he78, color='k', linestyle=':', linewidth=linewidth, alpha=1, label='Ref. 34 78K')

ax.plot(spectra.index, spectra['0-2ns'], color='darkred', linewidth=linewidth, alpha=0.25, label='2: 0ns')
ax.plot(spectra.index, spectra['32-64ns'], color='blue', linewidth=linewidth, alpha=0.25, label='2: 32ns')


ax.set_xlim([1.25, 1.95])
ax.set_ylim([0, 1])
    
ax.set_ylabel(r'PL Intensity (arb.)', fontsize=fontsize)
ax.set_xlabel('Energy (eV)', fontsize=fontsize)

ax = uf.linearticks(ax, xmajorsep=0.1, xminorsep=0.02, ymajorsep=0.2, yminorsep=0.1)
ax = uf.format_axes(ax, labelsize=fontsize)

ax.legend(frameon=False, loc='upper left', fontsize=lfontsize)

fig.savefig('figS33_all.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')
