import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf


here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1


# load data
scaling_factors = pd.read_csv(os.path.join(here, 'data', 'scaling_factors.csv'), header=0, index_col=0)

kinetics = pd.read_csv(os.path.join(here, 'data', 'pentacene_crystal2_kinetics.csv'), header=0, index_col=0)
spectrum1 = kinetics.loc[:, '128']/scaling_factors.loc[128, 'scaling factor']
spectrum2 = kinetics.loc[:, '256']/scaling_factors.loc[128, 'scaling factor']
spectrum3 = kinetics.loc[:, '64']/scaling_factors.loc[64, 'scaling factor']

spectrum1 /= 1e4
spectrum2 /= 1e4
spectrum3 /= 1e4

# create the plotting grid
fig, ax = plt.subplots(figsize=(7, 4.5))

ax.plot(spectrum3.index, spectrum3.values, 'b-', linewidth=linewidth, label='64ns')
ax.plot(spectrum1.index, spectrum1.values, 'k-', linewidth=linewidth, label='128ns')
ax.plot(spectrum2.index, spectrum2.values, 'r-', linewidth=linewidth, label='256ns')


ax.set_xlim([630, 850])
ax.set_ylim([0, 20])
    
ax.set_ylabel(r'PL Intensity (counts/10$^{4}$)', fontsize=fontsize)
ax.set_xlabel('Wavelength (nm)', fontsize=fontsize)

ax = uf.linearticks(ax, xmajorsep=25, xminorsep=5, ymajorsep=5, yminorsep=1)
ax = uf.format_axes(ax, labelsize=fontsize)

ax.legend(frameon=False, loc='upper left', fontsize=lfontsize)

fig.savefig('figS34_all.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')
