import os
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import usefulfunctions as uf


here = os.path.abspath(os.path.dirname(__file__))

# plot parameters
fontsize = 16
lfontsize = 16
fullpagewidth = 7
fmt = 'svg'
dpi = 300
linewidth = 1.5
alpha = 0.1


# load data
trs = ['2_4', '5_10', '10_20', '20_50']
data = {}
for tr in trs:
    spectra = pd.read_csv(os.path.join(here, 'data', '{0}ns_fluence.csv'.format(tr)), header=0, index_col=0)
    data[tr] = spectra/1e4


# create the plotting grid
fig, axes = plt.subplots(nrows=2, ncols=2, gridspec_kw={'hspace': 0.3, 'wspace': 0.25}, figsize=(14, 9))
axlist = axes.reshape(-1)

for i, tr in enumerate(trs):
    ax = axlist[i]
    
    spectra = data[tr]
    alphas = np.linspace(0.2, 1, 4)
    for ii, pe in enumerate(spectra.columns):
        
        ax.plot(spectra.index, spectra[str(pe)], 'b-', alpha=alphas[ii], linewidth=linewidth, label=r'{0:.1f}$\mu$Jcm$^{{-2}}$'.format(float(pe)))
    
    ax.set_xlim([630, 850])
    ax.set_ylim([0, 1.1*spectra.max().max()])
        
    ax.set_ylabel(r'PL Intensity (counts/10$^{4}$)', fontsize=fontsize)
    ax.set_xlabel('Wavelength (nm)', fontsize=fontsize)
    
    ax = uf.linearticks(ax, xmajorsep=25, xminorsep=5, ymajorsep=5, yminorsep=1)
    ax = uf.format_axes(ax, labelsize=fontsize)
    
    if i == 3:
        ax.legend(frameon=False, loc='upper left', fontsize=lfontsize)
    
    ax.set_title('{0}ns'.format(tr.replace('_', '-')), fontsize=fontsize, loc='left')

fig.savefig('figS35_all.{0}'.format(fmt), format=fmt, dpi=dpi, bbox_inches='tight')
