# Data and Figures #
This document is intended to act as a guide to the contents of this data package. A folder is provided for each figure in both the main article and supplementary information. Within each folder is a `data` folder containing all the data displayed in that figure. Also included is the python script used to generate the parts of the figure containing numerical data.

Please note that where figures contained data republished with permission from a third-party (3, 5, 6, S33), this data has been removed from both the `data` folder and the figure files included in this repository.

For information regarding experimental protocols and data analysis methods, please refer to the methods section and supplementary information for the publication.

## Contents ##
* [Index](#index)
    - [Main Article](#main-article)
      * [Figure 1](#figure-1)
      * [Figure 2](#figure-2)
      * [Figure 3](#figure-3)
      * [Figure 4](#figure-4)
      * [Figure 5](#figure-5)
      * [Figure 6](#figure-6)
    - [Supplementary Information](#supplementary-information)
      * [Figure S1](#figure-s1)
      * [Figure S2](#figure-s2)
      * [Figure S3](#figure-s3)
      * [Figure S4](#figure-s4)
      * [Figure S5](#figure-s5)
      * [Figure S6](#figure-s6)
      * [Figures S7-S12](#figures-s7-s12)
      * [Figure S13](#figure-s13)
      * [Figure S14](#figure-s14)
      * [Figure S15](#figure-s15)
      * [Figure S16](#figure-s16)
      * [Figure S17](#figure-s17)
      * [Figures S18-S23](#figures-s18-s23)
      * [Figure S24](#figure-s24)
      * [Figure S25](#figure-s25)
      * [Figure S26](#figure-s26)
      * [Figure S27](#figure-s27)
      * [Figure S28](#figure-s28)
      * [Figure S29](#figure-s29)
      * [Figure S30](#figure-s30)
      * [Figure S31](#figure-s31)
      * [Figure S32](#figure-s32)
      * [Figure S33](#figure-s33)
      * [Figure S34](#figure-s34)
      * [Figure S35](#figure-s35)
* [Figure Generation](#figure-generation)
* [Analysis and Simulation Code](#analysis-and-simulation-code)

## Index ##
Within each `data` folder are a series of `.csv` files containing numerical data. The index below indicates what data is included in each file and where it appears on the final figure.

#### Main Article ####

##### Figure 1 #####
_diftes thin film and pentacene single crystal characterisation_
- **diftes.cdx** is the ChemDraw file for the diftes molecule shown in panel a.
- **diF-TES-ADT_abs_RT.csv** contains the room temperature ground state absorption data for a diftes thin film and corresponds to the blue line in panel c.
- **diF-TES-ADT_pl.csv** contains steady-state PL data for a diftes film at room temperature and 100K. These are shown by the red and green lines respectively in panel c.
- **pentacene.cdx** is the ChemDraw file for the pentacene molecule shown in panel d.
- **pentacene_abs_RT.csv** contains the room temperature polarised absorption data for pentacene single crystal **1** shown in panel f.

##### Figure 2 #####
_triplet-pair emission in diftes_
- **diF-TES-ADT_spectra_100K_10e18cm3.csv** contains normalised time-gated PL spectra of a diftes film at 100K. Time ranges over which the PL was integrated are indicated in the column headings. The excitation density provided per pulse was 10<sup>18</sup> cm<sup>-3</sup>.

##### Figure 3 #####
_TRPL of diftes at 100K_
- **diF-TES-ADT_100K_1eXXcm3_MCR-ALS_kinetics.csv** contains the kinetics (normalised at 4ns) of the <sup>1</sup>(TT) PL spectral component extracted via MCR-ALS for the diftes film at 100K. The excitation density is indicated in the filename (XX=17,18,19). These are plotted as blue markers in panel d.
- **diF-TES-ADT_100K_1eXXcm3_MCR-ALS_spectra.csv** contains the S<sub>1</sub> and <sup>1</sup>(TT) PL spectral components extracted via MCR-ALS for the diftes film at 100K. The excitation density is indicated in the filename (XX=17,18,19). These are plotted as red and blue lines to the right of the false colour maps.
- **diF-TES-ADT_100K_1eXXcm3_TRPL.csv** contains the full TRPL matrix for the diftes film at 100K. The excitation density is indicated in the filename (XX=17,18,19). These are plotted as false colour maps in panels a, b and c.

##### Figure 4 #####
_excited state dynamics in diftes_
- **diF-TES-ADT_100K_T_Tmodel.csv** contains the normalised simulated populations of (T..T) at the three different excitation densities specified in the column headings. Plotted as green lines in panel b.
- **diF-TES-ADT_100K_T1model.csv** contains the normalised simulated populations of T<sub>1</sub> at the three different excitation densities specified in the column headings. Plotted as purple lines in panel b.
- **diF-TES-ADT_100K_TTmodel.csv** contains the normalised simulated populations of <sup>1</sup>(TT) at the three different excitation densities specified in the column headings. Plotted as red lines in panel b.
- **diF-TES-ADT_excimer_spectra_250K_1e17cm3.csv** contains the spectrum of the excimer at 20ns. The temperature was 250K and the excitation density was 10<sup>17</sup> cm<sup>-3</sup>. This spectrum was obtained by subtracting the spectrum at 500ns from that at 20ns, having normalised both to the S<sub>1</sub> peak, which doesn't spectrally overlap with the excimer. Plotted as a black dotted line in panel d.
- **diF-TES-ADT_MCR-ALS_TTkinetics_100K** contains the measured kinetics (normalised at 4ns) of the <sup>1</sup>(TT) PL spectral component extracted via MCR-ALS for the diftes film at 100K. The three different excitation densities are specified in the column headings. Plotted as blue markers in panel b.
- **mfe.csv** contains the measured magnetic field effect, &#916;PL/PL, of a drop-cast diftes crystal at room temperature for delay times of 20-30ns and 100-200ns. These are plotted as percentages with blue and orange markers respectively in panel c.
- **mfe_errors.csv** contains the errors associated with the measured values in **mfe.csv**. These were calculated from the differences in the measured PL when sweeping up and down in magnetic field. These are plotted as error bars in panel c.
- **simulations_20_30.csv** contains the simulated magnetic field effect for the 20-30ns time range. This is plotted as a solid blue line in panel c.
- **simulations_100_200.csv** contains the simulated magnetic field effect for the 100-200ns time range. This is plotted as a dashed orange line in panel c.

##### Figure 5 #####
_PL spectra of pentacene single crystals_
- **pentacene_crystal2_spectra.csv** contains the normalised PL spectra for pentacene single crystal **2** at time ranges of 0-2ns and 32-64ns. Also included in the file are smoothed data representing a rolling mean. These are all plotted in panel a as red (0-2ns) and blue (32-64ns) solid (raw) and dashed (smooth) lines.
- **pentacene_crystal3_spectra.csv** contains the normalised PL spectrum for pentacene single crystal **3** at a time range of 20-50ns. Also included in the file is data representing a rolling mean. These are both plotted in panel a as green solid (raw) and dashed (smooth) lines.
- **pentacene_crystal2_spectra_energy.csv** contains the same raw data as **pentacene_crystal2_spectra.csv**, but converted to an energy scale taking into account the Jacobian transformation. These are plotted as faint red (0-2ns) and blue (32-64ns) solid lines in panel c.
- **FranckCondon_model.csv** contains the simulated Franck-Condon vibronic progression (column name FC) plotted as a dashed black line in panel c. Also included, but not plotted, is the same progression with suppressed 0-0 (column name FC_sup0). For the calculation, the following parameters were used:
  - vibrational energy: 0.1463 eV
  - Huang Rhys parameter: 0.639
  - 0-0 energy: 1.663 eV
  - Gaussian broadening: 0.053 eV

##### Figure 6 #####
_TRPL of pentacene single crystals_
- **XXns_fluence.csv** contains the dependence of the pentacene single crystal **2** PL at 77K on pulse energy, for 690nm and 750nm. Columns with errors are also included; the errors were calculated from the noise in a 10nm spectral window around the central wavelength. The time range over which the PL was collected is indicated by XX in the filename. The data at 750nm are plotted as blue markers and error bars in panel e.
- **pentacene_crystal2_kinetic_slices.csv** contains the dependence of the pentacene single crystal **2** PL at 77K on time, normalised at 1ns, for 690nm and 750nm. Columns with errors are also included; the errors were calculated from the noise in a 10nm spectral window around the central wavelength. The pulse energy was 44&#181;Jcm<sup>-2</sup>. These data are plotted as red (690nm) and blue (750nm) markers and error bars in panel d.
- **pentacene_crystal2_kinetics.csv** contains the full TRPL dataset for pentacene single crystal **2** at 77K, normalised at 1ns. The pulse energy was 44&#181;Jcm<sup>-2</sup>. This dataset is plotted as a false colour map in panel c.
- **Poletayev2014_nsTA_simulation.csv** contains the simulated triplet transient absorption signal (<sup>1</sup>(TT) + T<sub>1</sub>) plotted as solid lines in panel b. Columns headings give the pulse energy in &#181;Jcm<sup>-2</sup>. The leftmost column is time in ns.
- **Poletayev2014_psTA_simulation.csv** contains the simulated triplet transient absorption signal (<sup>1</sup>(TT) + T<sub>1</sub>) plotted as solid lines in panel a. Columns headings give the pulse energy in &#181;Jcm<sup>-2</sup>. The leftmost column is time in ps.
- **simulated_TT_fluence.csv** contains the simulated dependence of the <sup>1</sup>(TT) PL on excitation pulse energy for the four different time ranges measured in experiment. These are plotted as black dashed lines in panel e.
- **TT_simulation_kinetics.csv** contains the simulated <sup>1</sup>(TT) PL dynamics plotted as a dashed black line in panel d.

#### Supplementary Information ####

##### Figure S1 #####
_GIWAXS analysis and AFM image of a diftes thin film_
- **measured_corrected.csv** contains the corrected diftes GIWAXS linecut data for the various &#967; angle integrations plotted in panel b.
- **simulations.csv** contains the simulated powder diffraction patterns for diftes plotted in panel b.

##### Figure S2 #####
_photograph of PVT furnace during first sublimation of pentacene_
- no numerical data

##### Figure S3 #####
_microscope images and thicknesses of all pentacene single crystals_
- **pentacene_thickness_XX.csv** contains the AFM measured edge profile of pentacene single crystal number XX, from which the thickness of the crystal was determined. These are plotted in panels j, k and l.

##### Figure S4 #####
_terraces on the surface of a pentacene single crystal_
- **pentacene_surface_1.csv** contains the AFM height profile of pentacene single crystal **2** plotted in panel b and indicated in panel a.

##### Figure S5 #####
_spectral sensitivity of the iCCD camera_
- **iCCD_correction_factor.csv** contains the measured correction for spectral sensitivity of the iCCD camera used for TRPL measurements. This was obtained using a calibrated light source. The columns are wavelength (nm) and correction factor. Note that in the figure, the inverse of the correction factor is plotted.

##### Figure S6 #####
_temperature-dependent absorption and PL of diftes_
- **diF-TES-ADT_abs.csv** contains the temperature dependent ground state absorbance of a diftes film. This is plotted in panel c and normalised in panel a.
- **diF-TES-ADT_pl.csv** contains the temperature dependent steady-state PL of a diftes film. This is plotted in panel d and normalised in panel b.

##### Figures S7-S12 #####
_TRPL and MCR-ALS species extraction for diftes_
- **diF-TES-ADT_XXK_1eYYcm3_MCR-ALS_kinetics.csv** contains the kinetics of the S<sub>1</sub> and <sup>1</sup>(TT) PL spectral components extracted via MCR-ALS for the diftes film at a temperature of XXK. The excitation density is indicated in the filename (YY=17,18,19). These are plotted as red and blue markers in the right hand column of the figure.
- **diF-TES-ADT_XXK_1eYYcm3_MCR-ALS_spectra.csv** contains the S<sub>1</sub> and <sup>1</sup>(TT) PL spectral components extracted via MCR-ALS for the diftes film at a temperature of XXK. The excitation density is indicated in the filename (YY=17,18,19). These are plotted as red and blue lines in the central column of the figure.
- **diF-TES-ADT_XXK_1eYYcm3_TRPL.csv** contains the full TRPL matrix for the diftes film at a temperature of XXK. The excitation density is indicated in the filename (YY=17,18,19). These are plotted as false colour maps in the left hand column of the figure.

##### Figure S13 #####
_transient absorption of diftes thin film and dilute solution at RT_
- **diF-TES-ADT_100uM_toluene_14uJcm2_kinetics_nir.csv** contains the kinetics of the transient absorption signal at 1200nm for diftes dissolved in anhydrous toluene at a concentration of 10<sup>-4</sup> M and sealed under nitrogen. The pulse energy is indicated in the filename. This data is not plotted in the figure.
- **diF-TES-ADT_100uM_toluene_14uJcm2_kinetics_vis.csv** contains the kinetics of the transient absorption signal at 430nm, 575nm and 720nm for diftes dissolved in anhydrous toluene at a concentration of 10<sup>-4</sup> M and sealed under nitrogen. The pulse energy is indicated in the filename. The data for 430nm is plotted in panel b.
- **diF-TES-ADT_100uM_toluene_14uJcm2_nir.csv** contains the full TA dataset in the NIR spectral region for diftes dissolved in anhydrous toluene at a concentration of 10<sup>-4</sup> M and sealed under nitrogen. The pulse energy is indicated in the filename.
- **diF-TES-ADT_100uM_toluene_14uJcm2_spectra.csv** contains the spectrum of the transient absorption signal at 1ps, 10ps, 100ps and 1ns for diftes dissolved in anhydrous toluene at a concentration of 10<sup>-4</sup> M and sealed under nitrogen. The pulse energy is indicated in the filename. These spectra are plotted in panel a.
- **diF-TES-ADT_100uM_toluene_14uJcm2_vis.csv** contains the full TA dataset in the UV-visible spectral region for diftes dissolved in anhydrous toluene at a concentration of 10<sup>-4</sup> M and sealed under nitrogen. The pulse energy is indicated in the filename.
- **diF-TES-ADT_film_35uJcm2_kinetics_nir.csv** contains the kinetics of the transient absorption signal at 900nm and 1200nm for an encapsulated diftes film. The pulse energy is indicated in the filename. This data is not plotted in the figure.
- **diF-TES-ADT_film_35uJcm2_kinetics_vis.csv** contains the kinetics of the transient absorption signal at 380nm, 430nm, 495nm, 560nm and 720nm for an encapsulated diftes film. The pulse energy is indicated in the filename. The data for 380nm, 430nm and 495nm is plotted in panel d.
- **diF-TES-ADT_film_35uJcm2_nir.csv** contains the full TA dataset in the NIR spectral region for an encapsulated diftes film. The pulse energy is indicated in the filename.
- **diF-TES-ADT_film_35uJcm2_spectra.csv** contains the spectrum of the transient absorption signal at 1ps, 10ps, 100ps and 1ns for an encapsulated diftes film. The pulse energy is indicated in the filename. These spectra are plotted in panel c.
- **diF-TES-ADT_film_35uJcm2_vis.csv** contains the full TA dataset in the UV-visible spectral region for an encapsulated diftes film. The pulse energy is indicated in the filename.

##### Figure S14 #####
_kinetic modelling of diftes at 100K: simple 3 state model_
- **diF-TES-ADT_100K_MCR-ALS_TT.csv** contains the measured kinetics (normalised at 4ns) of the <sup>1</sup>(TT) PL spectral component extracted via MCR-ALS for the diftes film at 100K. The three different excitation densities are specified in the column headings. Plotted as blue markers in panel b.
- **diF-TES-ADT_100K_model.csv** contains the normalised simulated populations of <sup>1</sup>(TT) at the three different excitation densities specified in the column headings. Plotted as red lines in panel b.
- **diF-TES-ADT_rates.csv** contains the rate constants used in the simulation of the <sup>1</sup>(TT) PL dynamics.

##### Figure S15 #####
_kinetic modelling of diftes at 100K: simple 3 state model including monomolecular triplet recombination_
- **diF-TES-ADT_100K_MCR-ALS_TT.csv** contains the measured kinetics (normalised at 4ns) of the <sup>1</sup>(TT) PL spectral component extracted via MCR-ALS for the diftes film at 100K. The three different excitation densities are specified in the column headings. Plotted as blue markers in panel b.
- **diF-TES-ADT_100K_model.csv** contains the normalised simulated populations of <sup>1</sup>(TT) at the three different excitation densities specified in the column headings. Plotted as red lines in panel b.
- **diF-TES-ADT_rates.csv** contains the rate constants used in the simulation of the <sup>1</sup>(TT) PL dynamics.

##### Figure S16 #####
_kinetic modelling of diftes: as in main text_
- **diF-TES-ADT_XXK_MCR-ALS_TT.csv** contains the measured kinetics (normalised at 4ns) of the <sup>1</sup>(TT) PL spectral component extracted via MCR-ALS for the diftes film for a temperature of XXK. The three different excitation densities are specified in the column headings. Plotted as blue markers in panels b-g.
- **diF-TES-ADT_XXK_model.csv** contains the normalised simulated populations of <sup>1</sup>(TT) at the three different excitation densities specified in the column headings for a temperature of XXK. Plotted as red lines in panels b-g.
- **diF-TES-ADT_rates.csv** contains the rate constants used in the simulations of the <sup>1</sup>(TT) PL dynamics. These rates are plotted in panels h-k.
- **diF-TES-ADT_rates_lowerbounds.csv** contains the lower values of the rate constants that caused a 20% increase in the cost function. These values define the negative error bars in panels h-k.
- **diF-TES-ADT_rates_upperbounds.csv** contains the upper values of the rate constants that caused a 20% increase in the cost function. These values define the positive error bars in panels h-k.

##### Figure S17 ####
_kinetic modelling of diftes: as in main text but without spin-lattice relaxation_
- **diF-TES-ADT_XXK_MCR-ALS_TT.csv** contains the measured kinetics (normalised at 4ns) of the <sup>1</sup>(TT) PL spectral component extracted via MCR-ALS for the diftes film for a temperature of XXK. The three different excitation densities are specified in the column headings. Plotted as blue markers in panels b-g.
- **diF-TES-ADT_XXK_model.csv** contains the normalised simulated populations of <sup>1</sup>(TT) at the three different excitation densities specified in the column headings for a temperature of XXK. Plotted as red lines in panels b-g.
- **diF-TES-ADT_rates.csv** contains the rate constants used in the simulations of the <sup>1</sup>(TT) PL dynamics. These rates are plotted in panels h-j.

##### Figures S18-S23 #####
_rate constant error analysis for diftes_
- **XXK_costvalues.csv** contains the value of the cost function obtained through optimisation of certain rate constants and the threshold value (20% higher) used to define the errors in the rate constants. Temperature given in filename (XX). These are plotted as dashed and solid horizontal lines.
- **XXK_kYY.csv** contains rate constant values and associated cost function value for rate constant YY. Temperature given in filename (XX). These are plotted as solid black lines.
- **XXK_rateswitherrors.csv** contains the values of the rate constants used for the simulation (solid vertical grey lines) together with the lower and upper bounds that caused a 20% increase in the cost function (red circles). Temperature given in filename (XX).

##### Figure S24 #####
_demonstration that TTA does not populate triplet-pairs via S<sub>1</sub> in diftes at 100K_
- **diF-TES-ADT_100K_Dovermodel_S1.csv** contains the simulated S<sub>1</sub> PL dynamics (normalised to the <sup>1</sup>(TT) PL at 4ns) assuming that bimolecular TTA populates S<sub>1</sub> directly rather than going through triplet-pair states. Plotted as black lines in panel a.
- **diF-TES-ADT_100K_Dovermodel_S1_20us_1e19cm3.csv** contains the predicted S<sub>1</sub> PL contribution relative to <sup>1</sup>(TT) at 20-25&#181;s assuming that bimolecular TTA populates S<sub>1</sub> directly rather than going through triplet-pair states. The spectral shape is given by the MCR-ALS extracted spectral component at 100K; the magnitude was determined through the kinetic modelling shown in panel a. Plotted as a red dashed line in panel b.
- **diF-TES-ADT_100K_Dovermodel_TT.csv** contains the simulated <sup>1</sup>(TT) PL dynamics (normalised at 4ns) assuming that bimolecular TTA populates S<sub>1</sub> directly rather than going through triplet-pair states. Plotted as red lines in panel a.
- **diF-TES-ADT_100K_MCR-ALS_TT.csv** contains the measured kinetics (normalised at 4ns) of the <sup>1</sup>(TT) PL spectral component extracted via MCR-ALS for the diftes film for a temperature of 100K. The three different excitation densities are specified in the column headings. Plotted as blue markers in panel b.
- **diF-TES-ADT_100K_measured_spectrum_20us_1e19cm3.csv** contains the measured, normalised diftes PL spectrum at 20-25&#181;s and 100K. Plotted as a blue line in panel b.

##### Figure S25 #####
_sensitised TTA in diftes at 100K_
- **fluencedep.csv** contains the dependence of the PL signal (gated between 200ns and 400ns) on excitation pulse energy using 725nm excitation. The columns are labelled as pure (diftes only) and doped (diftes + PdPc triplet sensitiser). Columns with errors are also included; errors are given as the standard deviation of the (spectrally resolved) background noise. These data are plotted as markers and error bars in panel b.
- **spectrumS1.csv** contains the MCR-ALS extracted S<sub>1</sub> component at 100K, scaled. Plotted as a red dashed line in panel a.
- **spectrumSF.csv** contains the measured, normalised diftes PL spectrum at 20-25&#181;s and 100K, under 532nm excitation. Plotted as a blue line in panel a.
- **spectrumTTA.csv** contains the upconverted PL spectrum measured in the 200ns to 400ns time range at 100K, for a diftes + PdPc sample excited at 725nm. The pulse energy was 961&#181;Jcm<sup>-2</sup>.

##### Figure S26 #####
_microscope image of dropcast diftes sample_
- no numerical data

##### Figure S27 #####
_reproducability of measured magnetic field effect in diftes_
- **XXns_YY.csv** contains the PL spectra measured under different applied magnetic fields (column headings, mT) in the time range given by XX. YY = up or dn indicates that the field was being swept up or down during the measurement. The excitation density was 7.2x10<sup>17</sup>cm<sup>-3</sup>; the measurement was performed at room temperature on a drop-cast sample.

##### Figure S28 #####
_magnetic field effect in diftes with simulation using model from main text_
- **crystal_kinetics.csv** contains the measured PL dynamics (spectrally integrated) of the drop-cast diftes sample under 532nm excitation with excitation density 7.2x10<sup>17</sup>cm<sup>-3</sup> at room temperature. Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. Plotted as red squares in panel a.
- **film_kinetics.csv** contains the measured PL dynamics (spectrally integrated) of the spin-coated diftes thin film under 532nm excitation with excitation density 10<sup>18</sup>cm<sup>-3</sup> at room temperature. Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. Plotted as green circles in panel a.
- **kinetics_rate_constant_modification.csv** contains the percentage change in the rate constants from the original values (used for the simulation in Figure [S16](#figure-s16)) and those used for the solid line in panel a. Plotted in panel b.
- **kinetics_simulation_new_rates.csv** contains simulated PL dynamics (contributions from S<sub>1</sub> and <sup>1</sup>(TT) weighted by their radiative rates). Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. The rate constants used are modified from the original ones as shown in panel b. Plotted as a solid line in panel a.
- **kinetics_simulation_old_rates.csv** contains simulated PL dynamics (contributions from S<sub>1</sub> and <sup>1</sup>(TT) weighted by their radiative rates). Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. The rate constants used are unchanged from the original ones except for the triplet decay rate which was set to zero. Plotted as a dashed line in panel a.
- **mfe.csv** contains the measured magnetic field effect, &#916;PL/PL, of a drop-cast diftes crystal at room temperature for delay times of 20-30ns and 100-200ns. These are plotted as percentages with blue and orange markers respectively in panel c.
- **mfe_errors.csv** contains the errors associated with the measured values in **mfe.csv**. These were calculated from the differences in the measured PL when sweeping up and down in magnetic field. These are plotted as error bars in panel c.
- **simulations_20_30.csv** contains the simulated magnetic field effect for the 20-30ns time range. The columns 0-20 index values of &#981;, the angle of the magnetic field in the (001) plane of the diftes crystal, linearly spaced between 0 and 2&#960;. Column 8 is plotted as a solid blue line in panels c and d. The mean plus or minus 4 standard deviations (with respect to the different &#981; values) are plotted as a dotted blue line and blue shading respectively in panel d.
- **simulations_100_200.csv** contains the simulated magnetic field effect for the 100-200ns time range. The columns 0-20 index values of &#981;, the angle of the magnetic field in the (001) plane of the diftes crystal, linearly spaced between 0 and 2&#960;. Column 8 is plotted as a solid blue line in panels c and d. The mean plus or minus 4 standard deviations (with respect to the different &#981; values) are plotted as a dotted blue line and blue shading respectively in panel d.

##### Figure S29 #####
_magnetic field effect in diftes with simulation using model from Figure [S24](#figure-s24)_
- **crystal_kinetics.csv** contains the measured PL dynamics (spectrally integrated) of the drop-cast diftes sample under 532nm excitation with excitation density 7.2x10<sup>17</sup>cm<sup>-3</sup> at room temperature. Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. Plotted as red squares in panel a.
- **film_kinetics.csv** contains the measured PL dynamics (spectrally integrated) of the spin-coated diftes thin film under 532nm excitation with excitation density 10<sup>18</sup>cm<sup>-3</sup> at room temperature. Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. Plotted as green circles in panel a.
- **kinetics_rate_constant_modification.csv** contains the percentage change in the rate constants from the original values (used for the simulation in Figure [S24](#figure-s24)) and those used for the solid line in panel a. Plotted in panel b.
- **kinetics_simulation_new_rates.csv** contains simulated PL dynamics (contributions from S<sub>1</sub> and <sup>1</sup>(TT) weighted by their radiative rates). Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. The rate constants used are modified from the original ones as shown in panel b. Plotted as a solid line in panel a.
- **kinetics_simulation_old_rates.csv** contains simulated PL dynamics (contributions from S<sub>1</sub> and <sup>1</sup>(TT) weighted by their radiative rates). Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. The rate constants used are unchanged from the original ones except for the triplet decay rate which was set to zero. Plotted as a dashed line in panel a.
- **mfe.csv** contains the measured magnetic field effect, &#916;PL/PL, of a drop-cast diftes crystal at room temperature for delay times of 20-30ns and 100-200ns. These are plotted as percentages with blue and orange markers respectively in panel c.
- **mfe_errors.csv** contains the errors associated with the measured values in **mfe.csv**. These were calculated from the differences in the measured PL when sweeping up and down in magnetic field. These are plotted as error bars in panel c.
- **simulations_20_30.csv** contains the simulated magnetic field effect for the 20-30ns time range. The columns 0-20 index values of &#981;, the angle of the magnetic field in the (001) plane of the diftes crystal, linearly spaced between 0 and 2&#960;. Column 8 is plotted as a solid blue line in panels c and d. The mean plus or minus 4 standard deviations (with respect to the different &#981; values) are plotted as a dotted blue line and blue shading respectively in panel d.
- **simulations_100_200.csv** contains the simulated magnetic field effect for the 100-200ns time range. The columns 0-20 index values of &#981;, the angle of the magnetic field in the (001) plane of the diftes crystal, linearly spaced between 0 and 2&#960;. Column 8 is plotted as a solid blue line in panels c and d. The mean plus or minus 4 standard deviations (with respect to the different &#981; values) are plotted as a dotted blue line and blue shading respectively in panel d.

##### Figure S30 #####
_magnetic field effect in diftes with simulation using Merrifield's model_
- **crystal_kinetics.csv** contains the measured PL dynamics (spectrally integrated) of the drop-cast diftes sample under 532nm excitation with excitation density 7.2x10<sup>17</sup>cm<sup>-3</sup> at room temperature. Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. Plotted as red squares in panel a.
- **kinetics_simulation_new_rates.csv** contains simulated PL dynamics (contributions from S<sub>1</sub> and <sup>1</sup>(TT) weighted by their radiative rates). Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. The rate constants used are modified from the original ones. Plotted as a solid line in panel a.
- **mfe.csv** contains the measured magnetic field effect, &#916;PL/PL, of a drop-cast diftes crystal at room temperature for delay times of 20-30ns and 100-200ns. These are plotted as percentages with blue and orange markers respectively in panel b.
- **mfe_errors.csv** contains the errors associated with the measured values in **mfe.csv**. These were calculated from the differences in the measured PL when sweeping up and down in magnetic field. These are plotted as error bars in panel b.
- **simulations_20_30.csv** contains the simulated magnetic field effect for the 20-30ns time range. The columns 0-20 index values of &#981;, the angle of the magnetic field in the (001) plane of the diftes crystal, linearly spaced between 0 and 2&#960;. The mean plus or minus 4 standard deviations (with respect to the different &#981; values) are plotted as a dotted blue line and blue shading respectively in panel b.
- **simulations_100_200.csv** contains the simulated magnetic field effect for the 100-200ns time range. The columns 0-20 index values of &#981;, the angle of the magnetic field in the (001) plane of the diftes crystal, linearly spaced between 0 and 2&#960;. The mean plus or minus 4 standard deviations (with respect to the different &#981; values) are plotted as a dotted blue line and blue shading respectively in panel b.

##### Figure S31 #####
_further variation of parameters for optimum magnetic field simulation_
- **crystal_kinetics.csv** contains the measured PL dynamics (spectrally integrated) of the drop-cast diftes sample under 532nm excitation with excitation density 7.2x10<sup>17</sup>cm<sup>-3</sup> at room temperature. Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. Plotted as red squares in panel a.
- **kinetics_rate_constant_further_modification.csv** contains the additional percentage change in the rate constants from the values used in Figure [S28](#figure-s28). Plotted as orange bars in panel b.
- **kinetics_rate_constant_modification.csv** contains the additional percentage change in the rate constants from the values used in Figure [S16](#figure-s16). Plotted as blue bars in panel b.
- **kinetics_simulation_new_rates.csv** contains simulated PL dynamics (contributions from S<sub>1</sub> and <sup>1</sup>(TT) weighted by their radiative rates). Left hand column is time (ns) and right hand column is PL signal, normalised at 4ns. The rate constants used are modified from the original ones as shown in panel b. Plotted as a solid line in panel a. Note that the final rate constant values used (in panel a here and in Figure [4](#figure-4)c) can be found [here](https://github.com/davidbossanyi/sfmodelling/blob/master/rates/diftes_rates_fig4c.csv).

##### Figure S32 #####
_excimers in diftes at 250K_
- **diF-TES-ADT_excimer_kinetics_250K_1e17cm3.csv** contains the extracted dynamics of the excimer, normalised at 20ns, seen in the diftes TRPL at 250K and an excitation density of 10<sup>17</sup>cm<sup>-3</sup>. The excimer spectrum at each time point was obtained by subtracting the PL spectrum at 500ns (no excimer present), first normalising both at the peak of the S<sub>1</sub> PL band. Plotted as orange-yellow markers in panel c.
- **diF-TES-ADT_excimer_kinetics_250K_1e17cm3.csv** contains the extracted spectra of the excimer seen in the diftes TRPL at 250K and an excitation density of 10<sup>17</sup>cm<sup>-3</sup>. The time points are indicated in the column headings. The first column is wavelength in nm. The excimer spectrum at each time point was obtained by subtracting the PL spectrum at 500ns (no excimer present), first normalising both at the peak of the S<sub>1</sub> PL band. Certain time points from this dataset are plotted in panel b.
- **diF-TES-ADT_simulation_250K_1e17cm3.csv** contains the simulated, normalised populations of the different excited state species in diftes (indicated in column headings) at 250K and an excitation density of 10<sup>17</sup>cm<sup>-3</sup>. The leftmost column gives time in ns. Plotted as solid lines in panel c.
- **diF-TES-ADT_total_spectra_250K_1e17cm3.csv** contains the PL spectra of the diftes film at 250K and an excitation density of 10<sup>17</sup>cm<sup>-3</sup>. The time points are indicated in the column headings. The spectra are normalised to the peak of the S<sub>1</sub> PL band. Certain time points from this dataset are plotted in panel a.

##### Figure S33 #####
_comparison of pentacene redshifted emission with literature_
- **pentacene_crystal2_spectra_energy.csv** contains the measured PL spectra of pentacene single crystal **2** at 77K at 0-2ns and 32-64ns. The data has been converted to an energy scale taking into account the Jacobian transformation. These are plotted as faint red (0-2ns) and blue (32-64ns) solid lines.

##### Figure S34 #####
_pentacene single crystal kinetics (raw delayed spectra)_
- **pentacene_crystal2_kinetics.csv** contains the full TRPL dataset for pentacene single crystal **2** at 77K. The pulse energy was 44&#181;Jcm<sup>-2</sup>. The last three time points from this dataset are plotted, scaled by the scaling factors used in the joining procedure for kinetic sections described in the methods. This is to recover the actual measured PL signal in counts.
- **scaling_factors.csv** contains the scaling factors and associated errors with which each kinetic section was adjusted so as to match the last (overlapped) time point of the previous kinetic section. See the methods section for details of this procedure.

##### Figure S35 #####
_pentacene single crystal time-gated intensity dependence (raw data)_
- **XXns_fluence.csv** contains the dependence of the pentacene single crystal **2** PL at 77K on pulse energy. Column headings are pulse energy values; the leftmost column is wavelength in nm. The time range over which the PL was collected is indicated by XX in the filename.

### Figure Generation ###

Figure parts containing numerical data were produced in `.svg` format using the python plotting library [matplotlib](https://matplotlib.org/). [Inkscape](https://inkscape.org/) was then used to assemble multi-panel figures. Any microscope images and photographs were included as rasterised objects. The python scripts used to produce figure panels containing numerical data are provided in each figure folder.

You will need an installation of python 3 (I used 3.8.5) on your machine in order to run the scripts. If you do not already have one, I recommend installing [miniconda](https://docs.conda.io/en/latest/miniconda.html).

You will need the following standard packages (my versions in brackets):
 - numpy (1.19.1)
 - matplotlib (3.2.2)
 - pandas (1.1.0)

You will also need a package called usefulfunctions which you can download and install following the instructions [here](https://github.com/davidbossanyi/useful-functions).

To generate parts of a figure, run for example:
```sh
cd Figure 2
python fig2.py
```

### Analysis and Simulation Code ###
Code to perform the simulations in Figures [4](#figure-4) and [6](#figure-6) is available [here](https://github.com/davidbossanyi/sfmodelling). A more complete python package for kinetic modelling of singlet fission systems is under development [here](https://github.com/davidbossanyi/triplet-pair-states). The python application that I used to process TRPL data taken with the iCCD camera can be found [here](https://github.com/fast-spectroscopy-sheffield/iCCD-kinetics). MCR-ALS is freely available [here](https://mcrals.wordpress.com/download/) as a Matlab GUI. The package used to perform Franck-Condon fitting is available [here](https://github.com/fast-spectroscopy-sheffield/franckcondon).
